Brief introduction
==================

First of all, we would like to thank you for taking the time to contribute! We
collected here useful pointers on how to participate in the Avocado community
and how to contribute.

And keep in mind that our procedures and guides are far from perfection, and
need constant improvements. Feel free to propose changes to this, or any other,
guide in a pull request.

Happy Hacking!
